package com.backendsys.service.Ai.Aiivh;


import com.backendsys.entity.Ai.Aiivh.AiPersonDTO;
import com.backendsys.entity.Ai.Aiivh.AiPersonTimbreCustomDTO;
import com.backendsys.entity.Ai.Aiivh.AiivhAnchorDTO;

import java.util.Map;

public interface AiivhMakeVirtualmanTaskService {
    Map<String, Object> queryAiivhMakeVirtualmanTaskList(Integer pageNum, Integer pageSize, AiPersonDTO aiPersonDTO);
    Map<String, Object> queryAiivhMakeVirtualmanTaskDetail(AiPersonDTO aiPersonDTO);
    Map<String, Object> insertAiivhMakeVirtualmanTask(AiPersonDTO aiPersonDTO);
    Map<String, Object> updateAiivhMakeVirtualmanTask(AiPersonDTO aiPersonDTO);



    Map<String, Object> insertAiivhAnchorCustom(AiivhAnchorDTO aiivhAnchorDTO);
    Map<String, Object> updateAiPersoneVirtualmanCustom(AiivhAnchorDTO aiivhAnchorDTO);

    Map<String, Object> insertAiPersoneTimbreCustom(AiPersonTimbreCustomDTO aiPersonTimbreCustomDTO);
    Map<String, Object> updateAiPersoneTimbreCustom(AiPersonTimbreCustomDTO aiPersonTimbreCustomDTO);
}
